#!/usr/bin/env bash

# shellcheck disable=SC1091
source "${ROOTDIR}/scripts/vars.sh"

function configure_dirs() {
    echo "* Configuring directories..."
}

# shellcheck disable=SC2162,SC2129
function configure_start() {
    echo "* Starting fidoip configuration."
    echo "! Password inputs aren't masked, ensure that you're alone :)"
    echo ""

    echo -n "Uplink IP or domain name: "
    read uplink_addr
    export UPLINK_ADDR="${uplink_addr}"

    echo -n "Uplink FTN address: "
    read uplink_ftn
    export UPLINK_FTN="${uplink_ftn}"

    echo -n "Uplink real name: "
    read uplink_name
    export UPLINK_NAME="${uplink_name}"

    echo -n "Your real name: "
    read real_name
    export REAL_NAME="${real_name}"

    echo -n "Your location (city, country): "
    read location
    export LOCATION="${location}"

    echo -n "Your FTN address: "
    read ftn_addr
    export FTN_ADDR="${ftn_addr}"

    echo -n "Your machine name: "
    read machine_name
    export MACHINE_NAME="${machine_name}"

    echo -n "Your password: "
    read password
    export PASSWORD="${password}"

    echo -n "AreaFix password: "
    read afpass
    export AREAFIX_PASSWORD="${afpass}"

    echo -n "FileFix password: "
    read ffpass
    export FILEFIX_PASSWORD="${ffpass}"

    echo "* Verify configuration:"
    echo ""
    echo "---"
    echo "Uplink address: ${UPLINK_ADDR}"
    echo "Uplink FTN: ${UPLINK_FTN}"
    echo "Uplink real name: ${UPLINK_NAME}"
    echo "---"
    echo "Your real name: ${REAL_NAME}"
    echo "Your FTN: ${FTN_ADDR}"
    echo "Your location: ${LOCATION}"
    echo "Your machine name: ${MACHINE_NAME}"
    echo "Your password: ${PASSWORD}"
    echo "---"
    echo "AreaFix password: ${AREAFIX_PASSWORD}"
    echo "FileFix password: ${FILEFIX_PASSWORD}"
    echo "---"
    echo ""

    echo -n "Is that correct? [y/N] "
    getresponse
    echo ""
    if [ "$(echo ${_RESP} | awk {' print tolower($1) '})" != "y" ]; then
        echo "! Please, restart configuration process!"
        exit 1
    fi

    echo "* Configuration confirmed."

    mkdir -p "${_CONFIG_ROOT}" "${_DATA_ROOT}"

    echo "export UPLINK_ADDR=${UPLINK_ADDR}" >"${ROOTDIR}/.config"
    echo "export UPLINK_FTN=${UPLINK_FTN}" >>"${ROOTDIR}/.config"
    echo "export UPLINK_NAME=${UPLINK_NAME}" >>"${ROOTDIR}/.config"
    echo "export REAL_NAME=${REAL_NAME}" >>"${ROOTDIR}/.config"
    echo "export FTN_ADDR=${FTN_ADDR}" >>"${ROOTDIR}/.config"
    echo "export LOCATION=${LOCATION}" >>"${ROOTDIR}/.config"
    echo "export MACHINE_NAME=${MACHINE_NAME}" >>"${ROOTDIR}/.config"
    echo "export PASSWORD=${PASSWORD}" >>"${ROOTDIR}/.config"
    echo "export AREAFIX_PASSWORD=${AREAFIX_PASSWORD}" >>"${ROOTDIR}/.config"
    echo "export FILEFIX_PASSWORD=${FILEFIX_PASSWORD}" >>"${ROOTDIR}/.config"

}

function getresponse() {
    stty raw
    _RESP=$(dd bs=1 count=1 2>/dev/null)
    export _RESP
    stty cooked
}
