#!/usr/bin/env bash

_GOLDED_BIN_DIR="${ROOTDIR}/dist/golded"
_GOLDED_GIT="https://github.com/golded-plus/golded-plus"

function golded_build() {
    echo "* Building golded+..."

    git_source "golded" "${_GOLDED_GIT}"

    cp "golded3/mygolded.__h" "golded3/mygolded.h"

    iconv -c -f cp866 -t utf8 docs/rusfaq.txt | sed 2s/cp866/utf-8/ >docs/rusfaq.utf8
    iconv -c -f cp866 -t utf8 docs/notework.rus | sed 2s/cp866/utf-8/ >docs/notework_rus.utf8
    iconv -c -f cp866 -t koi8-r docs/rusfaq.txt | sed 2s/cp866/koi8/ >docs/rusfaq.koi8
    iconv -c -f cp866 -t koi8-r docs/notework.rus | sed 2s/cp866/koi8/ >docs/notework_rus.koi8

    cd cfgs/config || (
        echo "! Failed to cd to configs directory!"
        exit 1
    )

    for i in *.ru?; do
        iconv -c -f cp866 -t koi8-r ${i} | sed 2s/cp866/koi8/ >${i}.koi8
        iconv -c -f cp866 -t utf-8 ${i} | sed 2s/cp866/utf-8/ >${i}.utf8
    done
    iconv -c -f cp866 -t koi8-r aliasru.cfg | sed 2s/cp866/koi8/ >aliasru.koi8
    iconv -c -f cp866 -t utf-8 aliasru.cfg | sed 2s/cp866/utf-8/ >aliasru.utf8

    cd ../template || (
        echo "! Failed to cd to templates directory!"
        exit 1
    )

    iconv -c -f cp866 -t koi8-r rusCP866.tpl | sed 2s/cp866/koi8/ >rusKOI8.tpl
    iconv -c -f cp866 -t utf-8 rusCP866.tpl | sed 2s/cp866/utf-8/ >rusUTF8.tpl

    cd ../.. || (
        echo "! Failed to cd to sources directory!"
        exit 1
    )

    make WIDE_NCURSES=0 USE_NCURSES=1 KOI8=1

    mkdir -p "${_GOLDED_BIN_DIR}/share/goldedplus"/{docs,charset,colorset,config,template}
    install -d "${_GOLDED_BIN_DIR}/bin"
    install -m 755 bin/rddtlnx "${_GOLDED_BIN_DIR}/bin/rddt"
    install -m 755 bin/gnlnx "${_GOLDED_BIN_DIR}/bin/goldnode"
    install -m 755 bin/gedlnx "${_GOLDED_BIN_DIR}/bin/gedlnx"
    install -m 755 ../golded "${_GOLDED_BIN_DIR}/bin/golded"
    patchelf --set-rpath /usr/lib/ncurses-golded/lib "${_GOLDED_BIN_DIR}/bin/gedlnx"
    install -d "${_GOLDED_BIN_DIR}/man/man1"
    install -m 644 docs/*.1 "${_GOLDED_BIN_DIR}/man/man1/"
    install -m 644 etc/gecolor.conf "${_GOLDED_BIN_DIR}/share/goldedplus/colorset/gedcolor.cfg"
    install -m 644 cfgs/config/* "${_GOLDED_BIN_DIR}/share/goldedplus/config"
    install -m 644 cfgs/template/* "${_GOLDED_BIN_DIR}/share/goldedplus/template"
    install -m 644 cfgs/charset/* "${_GOLDED_BIN_DIR}/share/goldedplus/charset"
    install -m 644 cfgs/colorset/* "${_GOLDED_BIN_DIR}/share/goldedplus/colorset"
    install -m 644 docs/*.utf8 "${_GOLDED_BIN_DIR}/share/goldedplus/docs"
    install -m 644 docs/*.koi8 "${_GOLDED_BIN_DIR}/share/goldedplus/docs"
    install -m 644 docs/{tips,linux,notework}.txt "${_GOLDED_BIN_DIR}/share/goldedplus/docs"
}

function golded_configure() {
    echo "* Configuring golded..."

    mkdir -p "${_CONFIG_ROOT}/golded"

    cat >"${_CONFIG_ROOT}/golded/golded.cfg" <<EOF
##################################################################
# Has to be in the coding KOI8-R codepage
##################################################################
username ${REAL_NAME}
Address ${FTN_ADDR}
XLATPATH ${_GOLDED_BIN_DIR}/share/goldedplus/charset/
XLATLOCALSET KOI8
XLATIMPORT CP866
XLATEXPORT CP866
XLATCHARSET KOI8 CP866 koi_866.chs
XLATCHARSET CP866 KOI8 866_koi.chs
IGNORECHARSET
CTRLINFONET TEARLINE, ORIGIN
CTRLINFOECHO TEARLINE, ORIGIN
CTRLINFOLOCAL TEARLINE, ORIGIN
TEARLINE binkd/1.1a-94/Darwin | hpt/mac 1.9.0-cur | @longpid @version
ORIGIN "Per Aspera Ad Astra"
TAGLINESUPPORT Yes
TAGLINE You_Tagline
COLOR MENU UNREAD YELLOW ON BLACK
HighlightUnread Yes
SEMAPHORE EXPORTLIST ${_DATA_ROOT}/logs/echotoss.log
SEMAPHORE IMPORTLIST ${_DATA_ROOT}/logs/import.log
AreaFile Fidoconfig ${_CONFIG_ROOT}/husky/areas.cfg
LOADLANGUAGE ${_CONFIG_ROOT}/golded/goldlang.cfg
AREASCAN *
EditSoftCrXLat H
UseSoftCRxlat Yes
DispSoftCr Yes
VIEWHIDDEN NO
VIEWKLUDGE NO
TwitName Bad User
TwitName Urgy Spammer
TwitMode Skip
TwitTo Yes
UuDecodePath ${_DATA_ROOT}/uudecode
Invalidate Tearline "" ""
Invalidate Origin "" ""
EditCrlFTerm No
ViewQuote Yes
ImportBegin -Cut On @file-
ImportEnd -Cut Off @file-
OutPutFile ${_DATA_ROOT}/outfile/
AttribsNet Loc Pvt
DispMsgSize Kbytes
DispAttachSize Kbytes
NodelistWarn No
TemplatePath ${_GOLDED_BIN_DIR}/share/goldedplus/template
Template golded.tpl "Default Template"
include ${_GOLDED_BIN_DIR}/share/goldedplus/colorset/gedcol10.cfg
NodePath ${_DATA_ROOT}/nodelist
NODELIST NODELIST.999
NODELIST PNT5005.999
NODELIST PNT5010.999
NODELIST PNT5019.999
NODELIST PNT5020.999
NODELIST PNT5025.999
NODELIST PNT5027.999
NODELIST PNT5033.999
NODELIST PNT5052.999
NODELIST PNT5057.999
NODELIST PNT5061.999
NODELIST PNT5080.999
RobotName AreaFix
RobotName AllFix
RobotName T-fix
RobotName FAQServer
LogFile ${_DATA_ROOT}/logs/golded.log
AddressMacro af,AreaFix,${UPLINK_FTN},"${AREAFIX_PASSWORD}"
AddressMacro ff,FileFix,${UPLINK_FTN},"${FILEFIX_PASSWORD}"
AddressBookAdd Always
^B READAddressBookAdd
@F10 READUserBase
AreaSep	!NET	"NM"	0	Net
AreaSep	!LOCAL	"Local"	0	Local
AreaSep	!ECHO	"Echos"	0	Echo
ConfirmFile golded.cfm
ConfirmResponse Ask
AREALISTGROUPID YES
AREALISTSORT TUE
PeekURLOptions FromTop
URLHANDLER -NoPause -NoKeepCtrl -Wipe xdg-open @url > /dev/null 2>&1 &
DispHdrLocation Yes
MsgListHeader 1
KeybExt Yes
QuoteCtrl No
Include ${_GOLDED_BIN_DIR}/share/goldedplus/config/aliasru.koi8
EOF
}

function golded_start() {
    echo "* Starting golded+..."
    luit -encoding ru_RU.KOI8-R "${_GOLDED_BIN_DIR}"/bin/gedlnx -c"${_CONFIG_ROOT}/golded/golded.cfg"
}
