#!/usr/bin/env bash

# shellcheck disable=SC1091
source "${ROOTDIR}/scripts/husky_vars.sh"

function husky_configure() {
    echo "* Configuring husky..."

    mkdir -p "${_CONFIG_ROOT}/husky"

    mkdir -p "${_DATA_ROOT}"/{announce,badarea,carbonarea,dupearea,fileecho,flags,inbound,magic,msgbasedir}
    mkdir -p "${_DATA_ROOT}"/{netmailarea,nodelist,outbound,protoinb,public,seq,tempinb,tempoutb,tics}

    cat >"${_CONFIG_ROOT}/husky/husky.cfg" <<EOF
Name ${MACHINE_NAME}
Sysop ${REAL_NAME}
Location ${LOCATION}
Address ${FTN_ADDR}}@fidonet
if "[module]"=="hpt"
Origin High Portable Tosser
else
endif
Inbound ${_DATA_ROOT}/inbound
ProtInbound ${_DATA_ROOT}/protinb
LocalInbound ${_DATA_ROOT}/localinb
Outbound ${_DATA_ROOT}/outbound
tempOutbound ${_DATA_ROOT}/tempoutb
tempInbound ${_DATA_ROOT}/tempinb
MsgBaseDir ${_DATA_ROOT}/msgbasedir
public ${_DATA_ROOT}/public
echotosslog ${_DATA_ROOT}/echotoss.log
importlog ${_DATA_ROOT}/import.log
logFileDir ${_DATA_ROOT}/
DupeHistoryDir ${_DATA_ROOT}/msgbasedir
NodelistDir ${_DATA_ROOT}/nodelist
magic ${_DATA_ROOT}/magic
lockfile ${_DATA_ROOT}/flags/hpt-lock
AdvStatisticsFile ${_DATA_ROOT}/hpt-adv.sta
NetmailFlag ${_DATA_ROOT}/flags/hpt-mail
SEQDIR ${_DATA_ROOT}/seq
AdvisoryLock 10
LogLevels 134567890ABCDEFGJKLMNT
LogEchoToScreen
nodelist ${_DATA_ROOT}/nodelist
LinkWithImportLog Kill
#########################################################################
# Так как hpt собран без поддержки архиваторов, то нужно установить
# консольные zip, unzip, unrar
# К примеру, использовать Macports - https://www.macports.org/
# Что это такое можно узнать тут - https://ru.wikipedia.org/wiki/MacPorts
#########################################################################
Unpack "unzip -joLqq \$a -d \$p" 0 504b0304
Pack zip zip -9jgq \$a \$f
Unpack "unrar e -y -c- -o+ -inul \$a \$p \$f" 0 52617221
LinkDefaults begin
ArcmailSize 400
PktSize 300
allowEmptyPktPwd secure
allowPktAddrDiffer off
#########################################################################
# Так как hpt собран без поддержки архиваторов, то нужно установить
# консольные zip, unzip, unrar
# К примеру, использовать Macports - https://www.macports.org/
# Что это такое можно узнать тут - https://ru.wikipedia.org/wiki/MacPorts
#########################################################################
Packer zip
Level 3000
AccessGrp A
ForwardRequests on
AutoCreate on
areafixName AreaFix
EchomailFlavour Direct
AutoAreaCreateSubdirs off
filefixName FileFix
FileEchoFlavour Normal
AutoFileCreateSubdirs off
LinkDefaults end
Link ${UPLINK_NAME}
Aka ${UPLINK_FTN}
OurAKA ${FTN_ADDR}
Password ${PASSWORD}
AreafixAutoCreateDefaults -b Jam -dupeCheck move -dupeHistory 14
AreafixAutoCreateFile ${_CONFIG_ROOT}/husky/areas.cfg
FilefixAutoCreateFile ${_CONFIG_ROOT}/husky/fileareas.cfg
LinkDefaults begin
ArcmailSize 400
PktSize 300
allowEmptyPktPwd secure
allowPktAddrDiffer off
#########################################################################
# Так как hpt собран без поддержки архиваторов, то нужно установить
# консольные zip, unzip, unrar
# К примеру, использовать Macports - https://www.macports.org/
# Что это такое можно узнать тут - https://ru.wikipedia.org/wiki/MacPorts
#########################################################################
Packer zip
Level 2500
AccessGrp A,L
ForwardRequests off
AutoCreate off
areafixName AreaFix
EchomailFlavour Normal
AutoAreaCreateSubdirs off
filefixName FileFix
FileEchoFlavour Hold
AutoFileCreateSubdirs off
LinkDefaults end
include ${_CONFIG_ROOT}/husky/areas.cfg
DupeBaseType HashDupesWMsgId
SeparateBundles
BundleNameStyle addrsCRC32
DefArcmailSize 300
ReportTo netmail
CarbonOut off
ExcludePassthroughCarbon
CarbonExcludeFwdFrom off
CarbonKeepSb
route crash ${UPLINK_FTN} *
fileAreaDefaults ${UPLINK_FTN}
OriginInAnnounce
ConvertLongNames Upper
ConvertShortNames Upper
FileDescName file_id.diz
FileDescPos 13
AnnounceSpool ${_DATA_ROOT}/announce
SaveTic * ${_DATA_ROOT}/tics
FileAreaBaseDir ${_DATA_ROOT}/fileecho
PassFileAreaDir ${_DATA_ROOT}/fileecho
Include ${_CONFIG_ROOT}/husky/fileareas.cfg
if "[module]"=="htick"
Origin High Portable Ticker
endif
EOF

    cat >"${_CONFIG_ROOT}/husky/areas.cfg" <<EOF
##################################################################
# Has to be in the coding KOI8-R codepage
##################################################################
EchoAreaDefaults -b Jam -dupecheck move -dupehistory 11
EchoAreaDefaults OFF
NetmailArea NetmailArea ${_DATA_ROOT}/netmailarea -b msg -d "NetMail"
BadArea BadArea ${_DATA_ROOT}/badarea -b msg -d "BadMail"
DupeArea DupeArea ${_DATA_ROOT}/dupearea/dupearea -b Jam -d "DupeMail"
dupebasetype HashDupes
areasmaxdupeage	20
LocalArea CarbonArea ${_DATA_ROOT}/carbonarea/carbonarea -b Jam -d "CarbonArea"
CarbonTo ${REAL_NAME}
CarbonCopy CarbonArea
EOF

    cat >"${_CONFIG_ROOT}/husky/fileareas.cfg" <<EOF
#
EOF

    echo "* Husky configured."
}
